import wafflecone

wafflecone.version()

male_seed = ["male", "he", "boy"]
female_seed = ["female", "she", "girl"]

exclude=["[CLS]", "[SEP]"]

calculator = wafflecone.calculator(path="./test_data/layer12.json",
                                   subspace_seeds=[male_seed, female_seed],
                                   exclude_words=exclude,
                                   user_friendly=True)
print(calculator.bias_sum_average())
print(calculator.bias_asb_sum_average())
calculator.save_summary()

wafflecone.visualize(3000)



def version():
    """Print the version of the package."""

def calculator(path: str,
              subspace_seeds: list[list[str]],
              random_token_num: int = None, # number of random tokens
              random_token_seed: int = None, # random seed
              subspace_folder_path: str = None, # folder path to save subspaces
              exclude_words: list[str] = None, # words to exclude from random tokens
              user_friendly: bool = None) -> 'Calculator':
    """Print the calculator."""


def visualize(port: int):
    """Visualize the calculator with web interface."""